from setuptools import setup, find_packages

setup(
    name='awacs',
    version='0.8.2',
    description="AWS Access Policy Language creation library",
    author="Mark Peek",
    author_email="mark@peek.org",
    url="https://github.com/cloudtools/awacs",
    license="New BSD license",
    packages=find_packages(),
    test_suite="tests",
    use_2to3=True,
    requires=['slimit'],
)
